@@ -35,8 +35,7 @@ if (!any(sysname == c("sunos", "darwin"))) {
     unlink(parser)
     cmd <- sprintf("%s/bin/R CMD SHLIB sample_parser.c %s ",
                    Sys.getenv("R_HOME"), base::basename(out));
-    sh <- "system";
-    do.call(sh,list(cmd,ignore.stdout=TRUE,ignore.stderr=TRUE));
+    system(cmd,ignore.stdout=FALSE,ignore.stderr=FALSE)
     unlink("Makevars");
     unlink(out);
     unlink(gsub("\\.c$",".h",out));
